@@ -45,7 +45,7 @@ function squirrelmail_plugin_init_proon() {
   //$squirrelmail_plugin_hooks['options_folder_inside']['proon'] = 'proon_link_STUB';
   $squirrelmail_plugin_hooks['left_main_after']['proon'] = 'proon_link_STUB';
   $squirrelmail_plugin_hooks['optpage_register_block']['proon'] = 'proon_optpage_STUB';
-  $squirrelmail_plugin_hooks['optpage_set_loadinfo']['proon'] = 'proon_optpage_loadinfo_STUB';
+  //$squirrelmail_plugin_hooks['optpage_set_loadinfo']['proon'] = 'proon_optpage_loadinfo_STUB';
 
   // This hook is responsible for conditionally converting auto_prune_sent stuff
   // into its prune equivalent.  We do a first-order condition on something cheap
